[tor-commits] [tor/master] minor cleanups on commit 17daab76

arma at torproject.org arma at torproject.org
Tue May 8 16:30:02 UTC 2018


commit c3ae14549d48cf9266b6442cce3bb15df613a7a8
Author: Roger Dingledine <arma at torproject.org>
Date:   Tue May 8 12:21:24 2018 -0400

    minor cleanups on commit 17daab76
    
    better punctuation and clearer wording
---
 src/or/hs_stats.c | 6 +++---
 src/or/status.c   | 6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/or/hs_stats.c b/src/or/hs_stats.c
index 3e183a5bf..1e2a96945 100644
--- a/src/or/hs_stats.c
+++ b/src/or/hs_stats.c
@@ -3,7 +3,7 @@
 
 /**
  * \file hs_stats.c
- * \brief Keeps stats about the activity of our hidden service.
+ * \brief Keeps stats about the activity of our onion service(s).
  **/
 
 #include "or.h"
@@ -42,14 +42,14 @@ hs_stats_get_n_introduce2_v2_cells(void)
   return n_introduce2_v2;
 }
 
-/** Note that we attempted to launch another circuit to a rendezvous point */
+/** Note that we attempted to launch another circuit to a rendezvous point. */
 void
 hs_stats_note_service_rendezvous_launch(void)
 {
   n_rendezvous_launches++;
 }
 
-/** Return the number of rendezvous circuits we have attempted to launch */
+/** Return the number of rendezvous circuits we have attempted to launch. */
 uint32_t
 hs_stats_get_n_rendezvous_launches(void)
 {
diff --git a/src/or/status.c b/src/or/status.c
index 4c497739e..4b8033d11 100644
--- a/src/or/status.c
+++ b/src/or/status.c
@@ -87,19 +87,19 @@ bytes_to_usage(uint64_t bytes)
   return bw_string;
 }
 
 /** Log some usage info about our hidden service */
 static void
 log_onion_service_stats(void)
 {
   unsigned int num_services = hs_service_get_num_services();
 
   /* If there are no active hidden services, no need to print logs */
   if (num_services == 0) {
     return;
   }
 
   log_notice(LD_HEARTBEAT,
-             "Our hidden service%s received %u v2 and %u v3 INTRODUCE2 cells "
+             "Our onion service%s received %u v2 and %u v3 INTRODUCE2 cells "
              "and attempted to launch %d rendezvous circuits.",
              num_services == 1 ? "" : "s",
              hs_stats_get_n_introduce2_v2_cells(),
@@ -87,19 +87,19 @@ bytes_to_usage(uint64_t bytes)
 }
 
-/** Log some usage info about our hidden service */
+/** Log some usage info about our onion service(s). */
 static void
 log_onion_service_stats(void)
@@ -87,19 +87,19 @@ bytes_to_usage(uint64_t bytes)
   unsigned int num_services = hs_service_get_num_services();
 
-  /* If there are no active hidden services, no need to print logs */
+  /* If there are no active onion services, no need to print logs */
   if (num_services == 0) {
     return;



More information about the tor-commits mailing list